@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -17,15 +17,16 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <mobius/io/bytearray_io.h>
 #include <mobius/io/reader_impl_bytearray.h>
+#include <mobius/io/writer_impl_bytearray.h>
 
 namespace mobius
 {
 namespace io
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief create new bytearray reader
+//! \brief Create new bytearray reader
 //! \param data bytearray
-//! \return reader
+//! \return Reader
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 mobius::io::reader
 new_bytearray_reader (const mobius::bytearray& data)
@@ -33,5 +34,16 @@ new_bytearray_reader (const mobius::bytearray& data)
   return mobius::io::reader (std::make_shared <reader_impl_bytearray> (data));
 }
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Create new bytearray writer
+//! \param data bytearray
+//! \return Writer
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+mobius::io::writer
+new_bytearray_writer (mobius::bytearray& data)
+{
+  return mobius::io::writer (std::make_shared <writer_impl_bytearray> (data));
+}
+
 } // namespace io
 } // namespace mobius
