@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -16,19 +16,14 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <mobius/unittest.h>
-#include <mobius/imagefile/imagefile.h>
-#include <mobius/imagefile/imagefile_raw.h>
-#include <mobius/imagefile/imagefile_split.h>
+#include <mobius/vfs/imagefile.h>
 
 static void
 testcase_imagefile_null ()
 {
-  mobius::unittest test ("mobius::imagefile::imagefile (null)");
+  mobius::unittest test ("mobius::vfs::imagefile (null)");
 
-  mobius::imagefile::imagefile imagefile;
-
-  // url
-  ASSERT_EXCEPTION (test, imagefile.get_url (), std::runtime_error);
+  mobius::vfs::imagefile imagefile;
 
   // get_type
   ASSERT_EXCEPTION (test, imagefile.get_type (), std::runtime_error);
@@ -54,13 +49,10 @@ testcase_imagefile_null ()
 static void
 testcase_imagefile_raw ()
 {
-  mobius::unittest test ("mobius::imagefile::imagefile (raw)");
+  mobius::unittest test ("mobius::vfs::imagefile (raw)");
 
   const std::string url = "file:///etc/hosts";
-  mobius::imagefile::imagefile_raw imagefile (mobius::imagefile::new_imagefile_from_url (url));
-
-  // url
-  test.ASSERT_EQUAL (imagefile.get_url (), url);
+  auto imagefile = mobius::vfs::new_imagefile_by_url (url, "raw");
 
   // get_type
   test.ASSERT_EQUAL (imagefile.get_type (), "raw");
@@ -75,13 +67,13 @@ testcase_imagefile_raw ()
   test.ASSERT_EQUAL (imagefile.get_sector_size (), 512);
 
   // get_last_metadata_time
-  test.ASSERT_TRUE (imagefile.get_last_metadata_time ());
+  test.ASSERT_TRUE (imagefile.get_attribute ("last_metadata_time").is_datetime ());
 
   // get_last_modification_time
-  test.ASSERT_TRUE (imagefile.get_last_modification_time ());
+  test.ASSERT_TRUE (imagefile.get_attribute ("last_modification_time").is_datetime ());
 
   // get_last_access_time
-  test.ASSERT_TRUE (imagefile.get_last_access_time ());
+  test.ASSERT_TRUE (imagefile.get_attribute ("last_access_time").is_datetime ());
 
   // new_reader
   auto reader = imagefile.new_reader ();
@@ -94,13 +86,13 @@ testcase_imagefile_raw ()
 static void
 testcase_imagefile_split ()
 {
-  mobius::unittest test ("mobius::imagefile::imagefile (split)");
+  mobius::unittest test ("mobius::vfs::imagefile (split)");
   const std::string url = "file:///tmp/unittest.001";
 
   // create imagefile
   {
-    mobius::imagefile::imagefile_split imagefile (mobius::imagefile::new_imagefile_from_url (url, "split"));
-    imagefile.set_segment_size (100000);
+    auto imagefile = mobius::vfs::new_imagefile_by_url (url, "split");
+    imagefile.set_attribute ("segment_size", 100000);
 
     auto writer = imagefile.new_writer ();
     writer.seek (100);
@@ -117,10 +109,7 @@ testcase_imagefile_split ()
   }
 
   // read imagefile created
-  mobius::imagefile::imagefile_split imagefile (mobius::imagefile::new_imagefile_from_url (url));
-
-  // url
-  test.ASSERT_EQUAL (imagefile.get_url (), url);
+  auto imagefile = mobius::vfs::new_imagefile_by_url (url);
 
   // get_type
   test.ASSERT_EQUAL (imagefile.get_type (), "split");
@@ -135,16 +124,16 @@ testcase_imagefile_split ()
   test.ASSERT_EQUAL (imagefile.get_sector_size (), 512);
 
   // get_segments
-  test.ASSERT_EQUAL (imagefile.get_segments (), 2);
+  test.ASSERT_EQUAL (imagefile.get_attribute ("segments"), 2);
 
   // get_segment_size
-  test.ASSERT_EQUAL (imagefile.get_segment_size (), 100000);
+  test.ASSERT_EQUAL (imagefile.get_attribute ("segment_size"), 100000);
 
   // get_acquisition_user
-  test.ASSERT_NOT_EQUAL (imagefile.get_acquisition_user (), std::string ());
+  test.ASSERT_NOT_EQUAL (imagefile.get_attribute ("acquisition_user"), std::string ());
 
   // get_acquisition_time
-  test.ASSERT_TRUE (imagefile.get_acquisition_time ());
+  test.ASSERT_TRUE (imagefile.get_attribute ("acquisition_time").is_datetime ());
 
   // data
   auto reader = imagefile.new_reader ();
